@@ -18,13 +18,13 @@ from lightwood.encoders import (
     TsNumericEncoder,
     CategoricalAutoEncoder,
     MultiHotEncoder,
-    DistilBertEncoder,
     DatetimeEncoder,
     Img2VecEncoder,
     TsRnnEncoder,
     TimeSeriesPlainEncoder,
     ShortTextEncoder,
-    VocabularyEncoder
+    VocabularyEncoder,
+    PretrainedLang,
 )
 
 
@@ -300,10 +300,9 @@ class DataSource(Dataset):
             ColumnDataTypes.MULTIPLE_CATEGORICAL: MultiHotEncoder,
             ColumnDataTypes.DATETIME: DatetimeEncoder,
             ColumnDataTypes.IMAGE: Img2VecEncoder,
-            ColumnDataTypes.TEXT: DistilBertEncoder,
+            ColumnDataTypes.TEXT: PretrainedLang,
             ColumnDataTypes.SHORT_TEXT: ShortTextEncoder,
             ColumnDataTypes.TIME_SERIES: TsRnnEncoder,
-            # ColumnDataTypes.AUDIO: AmplitudeTsEncoder
         }
 
         target_encoder_classes = {
